| Title: | Estimates Time of Concentration and Lag Time for Watersheds |
|---|---|
| Description: | Estimation of time of concentration and lag times for watersheds based on their morphometric characteristics. It includes various methods for calculation and offers plotting functionalities for comparative analysis. For more details see Bransby-Williams (1922, ISSN 2214-5818), Kirpich (1940) <https://hess.copernicus.org/articles/24/2655/2020/>, Kerby (1959, ISBN-13, 979-8355357214), Johnstone & Cross (1949, ISBN:9780823211234), California Division of Highways (1942, ISSN:0012-7353), Clark (1945) <doi:10.1061/TACEAT.0005800>, Giandotti (1934) <doi:10.1080/02626667.2017.1384549>, Passini (1972, ISBN:84-7433-040-8), Témez (1978, ISBN:84-7433-040-8), Pérez (1962, ISSN:0012-7353), Pilgrim (1977) <doi:10.1029/WR013i003p00587>, Bureau of Reclamation (1973, ISBN:9780913232123), Valencia-Zuluaga (1983) <https://repositorio.unal.edu.co/>, Ventura & Heras (1964) <doi:10.1061/9780784413548.005>, Soil Conservation Service (1972, ISBN:OL15009517M), Soil Conservation Service (1986) <https://www.ars.usda.gov/research/software/download/?softwareid=527>, US Navy - Technical Publication Navdocks (1972) <ISBN:978-1289256234>, Federal Aviation Administration (1970, ISBN:9780913236543), Natural Environment Research Council (1975, ISBN:9780114501234), Mimikou (1984) <doi:10.1080/02626668409490922>, Watt & Chow (1985) <doi:10.1139/l85-031>, Haktanir & Sezen (1990) <doi:10.1080/02626669009492423>. |
| Authors: | Alonso Arriagada [aut, cre] |
| Maintainer: | Alonso Arriagada <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0.0 |
| Built: | 2026-06-19 16:40:50 UTC |
| Source: | https://github.com/cran/Time.R |
A dataset containing IDs, areas, slopes, basin lengths, elevations, curve numbers, manning coefficients, and paved status for a series of watersheds.
data(Example_TimeR)data(Example_TimeR)
A data frame with 7 rows and 10 variables:
watersheds IDs
areas, in square kilometers
Slopes, in percentage
Basin lengths, in kilometers
Maximum elevations, in meters above sea level
Minimum elevations, in meters above sea level
Average elevations, in meters above sea level
Curve numbers, dimensionless
Manning coefficients, dimensionless
Paved status, TRUE or FALSE
Estimates time of concentration and lag time for watersheds using various methods.
Time.R_calc(data, plot_watershed = FALSE, plot_formulas = FALSE)Time.R_calc(data, plot_watershed = FALSE, plot_formulas = FALSE)
data |
A data frame containing watershed morphometric information. Required columns: watershed ID, area (km2), mean slope (%), basin length (km), max elevation (masl), min elevation (masl), average elevation (masl), curve number, manning coefficient, paved (TRUE/FALSE). |
plot_watershed |
A logical value. If TRUE, plots a comparative ggplot for each watershed. |
plot_formulas |
A logical value. If TRUE, plots a faceted ggplot to compare each formula for all watersheds. |
A data frame with calculated time of concentration and lag times.
# Load example data data("Example_TimeR") # Calculate time of concentration and lag time Time.R_calc(Example_TimeR, plot_watershed = FALSE, plot_formulas = FALSE) # Plot results by watersheds Time.R_calc(Example_TimeR, plot_watershed = TRUE, plot_formulas = FALSE) # Plot results by formulas Time.R_calc(Example_TimeR, plot_watershed = FALSE, plot_formulas = TRUE)# Load example data data("Example_TimeR") # Calculate time of concentration and lag time Time.R_calc(Example_TimeR, plot_watershed = FALSE, plot_formulas = FALSE) # Plot results by watersheds Time.R_calc(Example_TimeR, plot_watershed = TRUE, plot_formulas = FALSE) # Plot results by formulas Time.R_calc(Example_TimeR, plot_watershed = FALSE, plot_formulas = TRUE)