| Title: | Estimates Time of Concentration and Lag Time for Watersheds |
|---|---|
| Description: | Estimation of time of concentration and lag times for watersheds based on their morphometric characteristics. It includes various methods for calculation and offers plotting functionalities for comparative analysis. For more details see Bransby-Williams (1922) <https://tonyladson.net/2017/03/04/bransby-williams-formula/>, Kirpich (1940) <https://ascelibrary.org>, Kerby (1959) <https://ci.nii.ac.jp/en/articles/10018665342>, Johnstone & Cross (1949, ISBN:9780823211234), California Division of Highways (1942) <http://catalog.hathitrust.org/Record/002017818>, Clark (1945) <doi:10.1029/TR020i002p00141>, Giandotti (1934) <https://archivista.it/annali1934>, Passini (1972, ISBN:84-7433-040-8), Témez (1978, ISBN:84-7433-040-8), Pérez (1962) <https://revistaobraspublicas.com>, Pilgrim (1977) <doi:10.1029/WR013i003p00587>, Bureau of Reclamation (1973, ISBN:9780913232123), Valencia-Zuluaga (1983) <https://repositorio.unal.edu.co/>, Ventura & Heras (1964) <https://revistaobraspublicas.com>, Soil Conservation Service (1972, ISBN:OL15009517M), Soil Conservation Service (1986) <https://www.ars.usda.gov/research/software/download/?softwareid=527>, U.S. Navy (1972) <https://standards.globalspec.com/std/1434360/navy-navfac-dm-26>, Federal Aviation Administration (1970, ISBN:9780913236543), Natural Environment Research Council (1975, ISBN:9780114501234), Mimikou (1984) <doi:10.1016/0022-1694(84)90123-4>, Watt & Chow (1985) <doi:10.1139/l85-031>, Haktanir & Sezen (1990) <doi:10.1080/02626669009492423>. |
| Authors: | Alonso Arriagada [aut, cre] |
| Maintainer: | Alonso Arriagada <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0.0 |
| Built: | 2026-06-20 09:18:49 UTC |
| Source: | https://github.com/alobondo/time.r |
A dataset containing IDs, areas, slopes, basin lengths, elevations, curve numbers, manning coefficients, and paved status for a series of watersheds.
data(data)data(data)
A data frame with 66 rows and 10 variables:
watersheds IDs
areas, in square kilometers
Slopes, in percentage
Basin lengths, in kilometers
Maximum elevations, in meters above sea level
Minimum elevations, in meters above sea level
Average elevations, in meters above sea level
Curve numbers, dimensionless
Manning coefficients, dimensionless
Paved status, TRUE or FALSE
Estimates time of concentration and lag time for watersheds using various methods.
Time.R_calc(data, plot_watershed = FALSE, plot_formulas = FALSE)Time.R_calc(data, plot_watershed = FALSE, plot_formulas = FALSE)
data |
A data frame containing watershed morphometric information. Required columns: watershed ID, area (km2), mean slope (%), basin length (km), max elevation (masl), min elevation (masl), average elevation (masl), curve number, manning coefficient, paved (TRUE/FALSE). |
plot_watershed |
A logical value. If TRUE, plots a comparative ggplot for each watershed. |
plot_formulas |
A logical value. If TRUE, plots a faceted ggplot to compare each formula for all watersheds. |
A data frame with calculated time of concentration and lag times.