Package {Time.R}


Title: Estimates Time of Concentration and Lag Time for Watersheds
Version: 1.0.0
Date: 2026-05-27
Description: Estimation of time of concentration and lag times for watersheds based on their morphometric characteristics. It includes various methods for calculation and offers plotting functionalities for comparative analysis. For more details see Bransby-Williams (1922, ISSN 2214-5818), Kirpich (1940) https://hess.copernicus.org/articles/24/2655/2020/, Kerby (1959, ISBN-13, 979-8355357214), Johnstone & Cross (1949, ISBN:9780823211234), California Division of Highways (1942, ISSN:0012-7353), Clark (1945) <doi:10.1061/TACEAT.0005800>, Giandotti (1934) <doi:10.1080/02626667.2017.1384549>, Passini (1972, ISBN:84-7433-040-8), Témez (1978, ISBN:84-7433-040-8), Pérez (1962, ISSN:0012-7353), Pilgrim (1977) <doi:10.1029/WR013i003p00587>, Bureau of Reclamation (1973, ISBN:9780913232123), Valencia-Zuluaga (1983) https://repositorio.unal.edu.co/, Ventura & Heras (1964) <doi:10.1061/9780784413548.005>, Soil Conservation Service (1972, ISBN:OL15009517M), Soil Conservation Service (1986) https://www.ars.usda.gov/research/software/download/?softwareid=527, US Navy - Technical Publication Navdocks (1972) <ISBN:978-1289256234>, Federal Aviation Administration (1970, ISBN:9780913236543), Natural Environment Research Council (1975, ISBN:9780114501234), Mimikou (1984) <doi:10.1080/02626668409490922>, Watt & Chow (1985) <doi:10.1139/l85-031>, Haktanir & Sezen (1990) <doi:10.1080/02626669009492423>.
License: GPL-3
Encoding: UTF-8
Imports: ggplot2, readxl, utils
Suggests: rmarkdown, knitr
VignetteBuilder: knitr
Depends: R (≥ 3.5.0)
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-06-13 03:57:17 UTC; alobo
Author: Alonso Arriagada [aut, cre]
Maintainer: Alonso Arriagada <alonso.arriagada@usach.cl>
Repository: CRAN
Date/Publication: 2026-06-19 14:50:02 UTC

Series of watersheds characteristics used for testing the functions of the Time.R package.

Description

A dataset containing IDs, areas, slopes, basin lengths, elevations, curve numbers, manning coefficients, and paved status for a series of watersheds.

Usage

data(Example_TimeR)

Format

A data frame with 7 rows and 10 variables:

ID

watersheds IDs

Area_km2

areas, in square kilometers

Slope_perc

Slopes, in percentage

BasinLength_km

Basin lengths, in kilometers

Z_max_masl

Maximum elevations, in meters above sea level

Z_min_masl

Minimum elevations, in meters above sea level

Z_ave_masl

Average elevations, in meters above sea level

CurveNumber

Curve numbers, dimensionless

ManningCoeff

Manning coefficients, dimensionless

Paved

Paved status, TRUE or FALSE


Calculate Time of Concentration and Lag Time

Description

Estimates time of concentration and lag time for watersheds using various methods.

Usage

Time.R_calc(data, plot_watershed = FALSE, plot_formulas = FALSE)

Arguments

data

A data frame containing watershed morphometric information. Required columns: watershed ID, area (km2), mean slope (%), basin length (km), max elevation (masl), min elevation (masl), average elevation (masl), curve number, manning coefficient, paved (TRUE/FALSE).

plot_watershed

A logical value. If TRUE, plots a comparative ggplot for each watershed.

plot_formulas

A logical value. If TRUE, plots a faceted ggplot to compare each formula for all watersheds.

Value

A data frame with calculated time of concentration and lag times.

Examples


  # Load example data
  data("Example_TimeR")

  # Calculate time of concentration and lag time
  Time.R_calc(Example_TimeR, plot_watershed = FALSE, plot_formulas = FALSE)

  # Plot results by watersheds
  Time.R_calc(Example_TimeR, plot_watershed = TRUE, plot_formulas = FALSE)

  # Plot results by formulas
  Time.R_calc(Example_TimeR, plot_watershed = FALSE, plot_formulas = TRUE)